Documentation
¶
Index ¶
Constants ¶
const (
// WorkflowName is workflowId of the system workflow performing addition of search attributes
WorkflowName = "temporal-sys-add-search-attributes-workflow"
)
Variables ¶
var ( ErrUnableToUpdateESMapping = errors.New("unable to update Elasticsearch mapping") ErrUnableToExecuteActivity = errors.New("unable to execute activity") ErrUnableToGetSearchAttributes = errors.New("unable to get search attributes from cluster metadata") ErrUnableToSaveSearchAttributes = errors.New("unable to save search attributes to cluster metadata") )
Functions ¶
func AddSearchAttributesWorkflow ¶
func AddSearchAttributesWorkflow(ctx workflow.Context, params WorkflowParams) error
AddSearchAttributesWorkflow is the workflow that adds search attributes to the cluster for specific index.
Types ¶
type WorkflowParams ¶
type WorkflowParams struct {
// Elasticsearch index name. Can be empty string if Elasticsearch is not configured.
IndexName string
// Search attributes that need to be added to the index.
CustomAttributesToAdd map[string]enumspb.IndexedValueType
// If true skip Elasticsearch schema update and only update cluster metadata.
SkipSchemaUpdate bool
}
WorkflowParams is the parameters for add search attributes workflow.
Click to show internal directories.
Click to hide internal directories.