Documentation
¶
Overview ¶
Package parentclosepolicy is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProcessorActivity ¶
ProcessorActivity is activity for processing batch operation
func ProcessorWorkflow ¶
ProcessorWorkflow is the workflow that performs actions for ParentClosePolicy
Types ¶
type BootstrapParams ¶
type BootstrapParams struct {
// SdkSystemClient is an instance of temporal service client
SdkSystemClient sdkclient.Client
// MetricsClient is an instance of metrics object for emitting stats
MetricsClient metrics.Client
// Logger is the logger
Logger log.Logger
// Config contains the configuration for scanner
Config Config
// ClientBean is an instance of client.Bean for a collection of clients
ClientBean client.Bean
}
BootstrapParams contains the set of params needed to bootstrap the sub-system
type Config ¶ added in v1.12.0
type Config struct {
MaxConcurrentActivityExecutionSize dynamicconfig.IntPropertyFn
MaxConcurrentWorkflowTaskExecutionSize dynamicconfig.IntPropertyFn
MaxConcurrentActivityTaskPollers dynamicconfig.IntPropertyFn
MaxConcurrentWorkflowTaskPollers dynamicconfig.IntPropertyFn
}
Config defines the configuration for parent close policy worker
type MockClient ¶ added in v1.5.7
type MockClient struct {
// contains filtered or unexported fields
}
MockClient is a mock of Client interface.
func NewMockClient ¶ added in v1.5.7
func NewMockClient(ctrl *gomock.Controller) *MockClient
NewMockClient creates a new mock instance.
func (*MockClient) EXPECT ¶ added in v1.5.7
func (m *MockClient) EXPECT() *MockClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockClient) SendParentClosePolicyRequest ¶ added in v1.5.7
func (m *MockClient) SendParentClosePolicyRequest(arg0 Request) error
SendParentClosePolicyRequest mocks base method.
type MockClientMockRecorder ¶ added in v1.5.7
type MockClientMockRecorder struct {
// contains filtered or unexported fields
}
MockClientMockRecorder is the mock recorder for MockClient.
func (*MockClientMockRecorder) SendParentClosePolicyRequest ¶ added in v1.5.7
func (mr *MockClientMockRecorder) SendParentClosePolicyRequest(arg0 interface{}) *gomock.Call
SendParentClosePolicyRequest indicates an expected call of SendParentClosePolicyRequest.
type Processor ¶
type Processor struct {
// contains filtered or unexported fields
}
Processor is the background sub-system that execute workflow for ParentClosePolicy
type Request ¶
type Request struct {
// Deprecated: use Namespace in RequestDetail instead. Should be removed in 1.17
Namespace string
// Deprecated: use NamespaceID in RequestDetail instead. Should be removed in 1.17
NamespaceID string
Executions []RequestDetail
}
Request defines the request for parent close policy
type RequestDetail ¶
type RequestDetail struct {
Namespace string
NamespaceID string
WorkflowID string
RunID string
Policy enumspb.ParentClosePolicy
}
RequestDetail defines detail of each workflow to process